#!/bin/bash

basedir=`pwd`

# Determine the update mode.
git=true
for dir in libraries/d*
do
  if ! [ -d "$basedir/$dir/.git" ]
  then
    git=false
    break
  fi
done

# Update libraries.
if [ $git == true ]
then
  echo -e "# Rebuilding DrupalAPI reference sources via GIT"
  for dir in libraries/d*
  do
    cd $basedir/$dir
    echo -en "$dir       \r"
    git pull > /dev/null
  done
  cd $basedir
else
  echo -e "# Rebuilding DrupalAPI reference sources via Drush make"
  echo -en "drush make --yes --working-copy --no-core --contrib-destination=. ./libraries/libraries.make\r"
  drush make -q --yes --working-copy --no-core --contrib-destination=. ./libraries/libraries.make 2> /dev/null
fi

# Run Drush queue runner.
for dir in ../../sites/*
do
  if [ -f "$basedir/$dir/settings.php" ]
  then
    cd $basedir/$dir
    install_profile=`drush vget install_profile`
    if echo "$install_profile" | grep -q drupalapi
    then
      echo -e "# Updating DrupalAPI reference"
      count=`drush queue-list | grep 'api_parse' | sed -e 's/[^0-9]//g'`
      if [ $count -eq 0 ]
      then
        echo -en "Initializing update\r"
        drush cron -q 2> /dev/null
        count=`drush queue-list | grep 'api_parse' | sed -e 's/[^0-9]//g'`
      fi
      while [ $count -gt 0 ]
      do
        echo -en "$count items remaining   \r"
        drush queue-run api_parse -q 2> /dev/null
        count=`drush queue-list | grep 'api_parse' | sed -e 's/[^0-9]//g'`
      done
    fi
  fi
done
cd $basedir
